@@ -20,6 +20,10 @@ from .diff_utils import (
     map_original_to_new_line,
     map_new_to_original_line
 )
+from .logging import (
+    get_logger,
+    set_log_level
+)
 
 __all__ = [
     # GitHub API functions
@@ -35,5 +39,9 @@ __all__ = [
     'extract_function_diff_from_patch',
     'get_changed_line_numbers',
     'map_original_to_new_line',
-    'map_new_to_original_line'
+    'map_new_to_original_line',
+    
+    # Logging utilities
+    'get_logger',
+    'set_log_level'
 ] 
\ No newline at end of file
