@@ -7,11 +7,11 @@ and mapping changes to line numbers in files.
 
 import re
 from typing import Dict, List, Tuple, Optional, Set, NamedTuple
-import logging
 import difflib
+from .logging import get_logger
 
 # Set up logging
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 # Define data structures for diff information
 class HunkHeader(NamedTuple):
@@ -177,7 +177,7 @@ def _parse_file_diff(lines: List[str], start_idx: int) -> Optional[FileDiff]:
     else:
         # If no +++ line, use the fallback values from diff --git
         if not new_file:
-            logger.warning("Failed to parse +++ line, using fallback")
+            logger.warning("Failed to parse +++ line", using="fallback", old_file=old_file)
             if is_deleted:
                 new_file = "b/" + old_file[2:]  # Use old path with b/ prefix
         i += 1
@@ -267,7 +267,9 @@ def _parse_hunk(lines: List[str], start_idx: int) -> Optional[Tuple[HunkHeader,
     # Parse hunk header
     header_match = RE_HUNK_HEADER.match(lines[start_idx])
     if not header_match:
-        logger.error(f"Failed to parse hunk header: {lines[start_idx]}")
+        logger.error("Failed to parse hunk header", 
+                    line=lines[start_idx],
+                    position=start_idx)
         return None
     
     original_start = int(header_match.group(1))
@@ -635,7 +637,9 @@ def parse_github_patch(patch: str, file_path: str) -> Optional[FileDiff]:
         FileDiff object with the parsed patch details
     """
     if not patch or not patch.startswith('@@'):
-        logger.warning(f"Not a valid GitHub API patch: {patch[:20]}...")
+        logger.warning("Not a valid GitHub API patch", 
+                      patch_prefix=patch[:20] if len(patch) > 20 else patch,
+                      file_path=file_path)
         return None
     
     # Set up file paths
@@ -659,7 +663,9 @@ def parse_github_patch(patch: str, file_path: str) -> Optional[FileDiff]:
             
         header_match = RE_HUNK_HEADER.match(lines[i])
         if not header_match:
-            logger.warning(f"Failed to parse hunk header: {lines[i]}")
+            logger.warning("Failed to parse hunk header", 
+                          line=lines[i], 
+                          file_path=file_path)
             i += 1
             continue
         
